@@ -3,7 +3,7 @@
 ;;                     Patrick LoPresti <patl@lcs.mit.edu>
 ;;               1998  Brian Warner <warner@lothar.com>
 
-;; $Id: mc-gpg.el,v 1.19 2001/09/26 06:36:00 warner Exp $
+;; $Id: mc-gpg.el,v 1.21 2002/09/25 00:12:55 warner Exp $
 
 ;;{{{ Licensing
 ;; This file is intended to be used with GNU Emacs.
@@ -71,6 +71,9 @@
 (defvar mc-gpg-path "gpg" "*The GPG executable.")
 (defvar mc-gpg-display-snarf-output nil
   "*If t, pop up the GPG output window when snarfing keys.")
+(defvar mc-gpg-always-fetch 'never
+  "*If t, always fetch missing keys. If 'never, never fetch. If nil,
+ask the user.")
 (defvar mc-gpg-alternate-keyring nil
   "*Public keyring to use instead of default.")
 (defvar mc-gpg-comment
@@ -915,7 +918,7 @@ GPG ID.")
 	  ;; key is nil if CONVENTIONAL, (string . hexid) otherwise
 	  (setq passwd
 		(if key
-		    (mc-activate-passwd (car key)
+		    (mc-activate-passwd (cdr key)
 					(format 
 					 "GPG passphrase for %s (%s): "
 					 (car key) (cdr key)))
@@ -959,7 +962,8 @@ GPG ID.")
 	 ((atom sig) ;; don't have the signature key
 	  (progn
 	    ;; offer to fetch the key, then what? run again? must we undo 1st?
-	    (message (format "cannot check signature from keyid %s" sig))
+	    (mc-message-sigstatus
+             (format "cannot check signature from keyid %s" sig))
 	    (if (and (not (eq mc-gpg-always-fetch 'never))
 		     (or mc-gpg-always-fetch
 			 (y-or-n-p
@@ -973,15 +977,16 @@ GPG ID.")
 	    ))
 	 ((nth 0 sig) ;; good signature
 	  (progn
-	    (message (mc-gpg-format-sigline 
-		      t (nth 1 sig) (nth 2 sig) (nth 3 sig)))
+	    (mc-message-sigstatus (mc-gpg-format-sigline 
+				   t (nth 1 sig) (nth 2 sig) (nth 3 sig)))
 	    '(t . t)
 	    ))
 	 (t ;; bad signature
 	  (progn
-	    (ding)
-	    (message (mc-gpg-format-sigline 
-		      nil (nth 1 sig) (nth 2 sig) (nth 3 sig)))
+	    (mc-message-sigstatus (mc-gpg-format-sigline 
+				   nil (nth 1 sig) (nth 2 sig) (nth 3 sig))
+				  t ; get their attention
+				  )
 	    '(t . nil)
 	    ))
        )))
@@ -998,7 +1003,7 @@ GPG ID.")
     (setq key (mc-gpg-lookup-key (or id mc-gpg-user-id) 'sign))
     (setq passwd
 	  (mc-activate-passwd
-	   (car key)
+	   (cdr key)
 	   (format "GPG passphrase for %s (%s): " (car key) (cdr key))))
     (setq args
 	  (list
